@@ -3,7 +3,13 @@
 #########################################################
 
 get.block <- function(occ, bg.coords){
-	# SPLIT OCC POINTS INTO FOUR SPATIAL GROUPS
+	
+  occ <- as.data.frame(occ)
+  rownames(occ) <- 1:nrow(occ)
+  bg.coords <- as.data.frame(bg.coords)
+  rownames(bg.coords) <- 1:nrow(bg.coords)
+
+  # SPLIT OCC POINTS INTO FOUR SPATIAL GROUPS
 	noccs <- nrow(occ)
 	n1 <- ceiling(nrow(occ)/2)
 	n2 <- floor(nrow(occ)/2)
@@ -17,9 +23,9 @@ get.block <- function(occ, bg.coords){
 	grp4 <- grpB[!rownames(grpB)%in%rownames(grp3),]
 
 	# SPLIT BACKGROUND POINTS BASED ON SPATIAL GROUPS
-	bvert <- mean(max(grp1[, 1]), min(grp2[, 1]))
-	tvert <- mean(max(grp3[, 1]), min(grp4[, 1]))
-	horz <- mean(max(grpA[, 2]), min(grpB[, 2]))
+	bvert <- mean(c(max(grp1[, 1]), min(grp2[, 1])))
+	tvert <- mean(c(max(grp3[, 1]), min(grp4[, 1])))
+	horz <- mean(c(max(grpA[, 2]), min(grpB[, 2])))
 	bggrp1 <- bg.coords[bg.coords[, 2] <= horz & bg.coords[, 1]<bvert,]
 	bggrp2 <- bg.coords[bg.coords[, 2] < horz & bg.coords[, 1]>=bvert,]
 	bggrp3 <- bg.coords[bg.coords[, 2] > horz & bg.coords[, 1]<=tvert,]
